@@ -167,8 +167,10 @@ class Controller():
             rtUser=self.save_a_user(rtUser)
             rt["user"]=rtUser["id"]
             rt["author"]=rtUser["id"]
+            #print "save_a_status rt id ", rt["id"]
             r=self.dao.get_a_status_by_id(account, rt["id"])
             if r==None:
+                #print "save_a_status, add rt id ", rt["id"]
                 self.dao.add_a_status(rt)
             rt["user"]=rtUser
             rt["author"]=rtUser
@@ -220,19 +222,24 @@ class Controller():
         self.dao.del_status_by_id(account,id)
 
     def save_a_user(self,user):
+        #print "save_a_user"
         if user!=None:
             account=user["account"]
             id=user["id"]
             r=self.dao.get_a_user_by_id(account, id)
             if r==None:
+                #print "create :",user["screen_name"], user["avatar_large"]
                 self.dao.add_a_user(user)
             else:
+                #print "update :",user["screen_name"], user["avatar_large"]
                 self.dao.update_a_user(user)
             return user
 
     def get_a_user_by_id(self,account,id):
         return self.dao.get_a_user_by_id(account, id)
-
+        
+    def get_a_user_by_sname(self,account,sname):
+        return self.dao.get_a_user_by_id(account, sname)
 
     def save_settings(self,settings):
         if settings!=None:
